package com.cht.tas.ap;

import org.json.JSONArray;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

import java.util.Map;

/**
 * 執行定時 callout 的程式
 */
@Component
public class Callout {
    private final Logger logger = LoggerFactory.getLogger(Callout.class);

    @Autowired
    private IoTTas ioTTAS;

    /**
     * 透過 spring boot @Scheduled 標示，設定每 5 分鐘 (300,000 ms) 執行一次 callout API 發出電話通告
     */
    @Scheduled(fixedDelay = 300_000)
    public void calloutSchedule() {
        JSONArray phones = new JSONArray();
        //初始化設定要撥出電話的號碼清單。在 IoTTas.java 檔中設定清單內容
        for (Map.Entry<String, String> entry : ioTTAS.phonePools.entrySet()) {
            //加入未回應問券內容的電話號碼，並進行撥號
            if (entry.getValue().equals("0")) {
                phones.put(entry.getKey());
            }
        }

        if (!phones.isEmpty()) {
            //取得 HTTP callout API 要填入的 JSON 訊息內容
            String postData = ioTTAS.calloutIVR(phones);
            //呼叫 API 發出電話 callout
            ioTTAS.callout(postData);
        } else {
            logger.debug("no phone number in phones array");
        }
    }
}
