package com.cht.tas.ap;

import org.eclipse.paho.client.mqttv3.MqttMessage;
import org.json.JSONObject;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

/**
 * 用於處理透過 callout API 撥出電話給用戶時，產生要送入到 callAction topic 的訊息
 */
@Component
public class CalloutEvent {
    private final Logger logger = LoggerFactory.getLogger(CalloutEvent.class);

    @Value("${mqtt.phone-conn.actionTopic}")
    private String actionTopic = "";

    @Autowired
    private IoTTas ioTTas;

    /**
     * 控制電話發出問券調查的詢問語句
     *
     * @param reqJObjs //從 callEvent topic 收到的 id 數值，要 copy 並送到 callAction topic 中
     */
    public void menu(JSONObject reqJObjs) {
        JSONObject respJObjs = new JSONObject();
        //從 callEvent topic 收到的 id 數值，要 copy 並送到 callAction topic 中
        respJObjs.put("id", reqJObjs.getString("id"));

        respJObjs.put("node", "MyAskNode");
        respJObjs.put("text", "請問您對本次在阿忠小吃用餐的滿意度如何？滿意請按1，待改進請按2");
        respJObjs.put("collectDTMF", true);

        MqttMessage message = new MqttMessage(respJObjs.toString().getBytes());
        //將訊息發送到 callAction topic 給遠端伺服器
        MqttTas.publish(actionTopic, message);
    }

    /**
     * 控制播音回應用戶端，表示已收到問券調查結果
     *
     * @param reqJObjs 從 callEvent topic 收到的 id 數值，要 copy 並送到 callAction topic 中
     * @param param    用戶透過電話按鍵輸入的數字鍵
     */
    public void myAskNode(JSONObject reqJObjs, String param) {
        JSONObject respJObjs = new JSONObject();
        String phone = reqJObjs.getString("phone");
        //從 callEvent topic 收到的 id 數值，要 copy 並送到 callAction topic 中
        respJObjs.put("id", reqJObjs.getString("id"));

        //收集 param 資料即可知道用戶按下的滿意度內容
        ioTTas.phonePools.put(phone, param);

        respJObjs.put("node", "byebye");
        respJObjs.put("text", "感謝回答，祝您有美好的一天，再見");
        respJObjs.put("nextNode", "END");

        MqttMessage message = new MqttMessage(respJObjs.toString().getBytes());
        //將訊息發送到 callAction topic 給遠端伺服器
        MqttTas.publish(actionTopic, message);
    }
}
