package com.cht.tas.ap;

import org.eclipse.paho.client.mqttv3.MqttMessage;
import org.json.JSONObject;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

/**
 * 用於處理用戶回撥電話 (call-in) 到 TAS 系統時，用於產生回應到 MQTT callAction topic 的訊息
 */
@Component
public class IVREvent {
    private final Logger logger = LoggerFactory.getLogger(IVREvent.class);

    @Value("${mqtt.phone-conn.actionTopic}")
    private String actionTopic = "";

    @Autowired
    private IoTTas ioTTas;

    public void menu(JSONObject reqJObjs) {
        JSONObject respJObjs = new JSONObject();
        respJObjs.put("id", reqJObjs.getString("id"));

        respJObjs.put("node", "MyAskNode");
        respJObjs.put("text", "請問您對本次在阿忠小吃用餐的滿意度如何？滿意請按1，待改進請按2");
        respJObjs.put("collectDTMF", true);

        MqttMessage message = new MqttMessage(respJObjs.toString().getBytes());
        MqttTas.publish(actionTopic, message);
    }

    public void myAskNode(JSONObject reqJObjs, String param) {
        JSONObject respJObjs = new JSONObject();
        String phone = reqJObjs.getString("phone");

        respJObjs.put("id", reqJObjs.getString("id"));

        //收集 param 資料即可知道用戶按下的滿意度內容
        ioTTas.phonePools.put(phone, param);

        respJObjs.put("node", "byebye");
        respJObjs.put("text", "感謝回答，祝您有美好的一天，再見");
        respJObjs.put("nextNode", "END");

        MqttMessage message = new MqttMessage(respJObjs.toString().getBytes());
        MqttTas.publish(actionTopic, message);
    }

    public void alreadyAsk(JSONObject reqJObjs) {
        JSONObject respJObjs = new JSONObject();
        respJObjs.put("id", reqJObjs.getString("id"));

        //收集 param 資料即可知道用戶按下的滿意度內容

        respJObjs.put("node", "byebye");
        respJObjs.put("text", "您已回答過本問題，謝謝，祝您有美好的一天，再見");
        respJObjs.put("nextNode", "END");

        MqttMessage message = new MqttMessage(respJObjs.toString().getBytes());
        MqttTas.publish(actionTopic, message);
    }

    public void wrongAsk(JSONObject reqJObjs) {
        JSONObject respJObjs = new JSONObject();
        respJObjs.put("id", reqJObjs.getString("id"));

        //收集 param 資料即可知道用戶按下的滿意度內容

        respJObjs.put("node", "byebye");
        respJObjs.put("text", "您不是本次問卷調查的對象，謝謝，祝您有美好的一天，再見");
        respJObjs.put("nextNode", "END");

        MqttMessage message = new MqttMessage(respJObjs.toString().getBytes());
        MqttTas.publish(actionTopic, message);
    }
}
