package com.cht.tas.ap;

import jakarta.annotation.PostConstruct;
import okhttp3.*;
import org.jetbrains.annotations.NotNull;
import org.json.JSONArray;
import org.json.JSONObject;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

import java.io.IOException;
import java.util.HashMap;
import java.util.Map;

@Component
public class IoTTas {
    private static OkHttpClient httpClient;
    private final Logger logger = LoggerFactory.getLogger(IoTTas.class);
    @Value("${mqtt.phone-conn.serviceNumber}")
    private String serviceNumber = "";
    @Value("${mqtt.phone-conn.apiKey}")
    private String apiKey;
    @Value("${phone-conn.callout.url}")
    private String calloutURL = "";

    //存放撥出電話號碼清單及記錄用戶回應時按下的 DTMF 數字鍵。初始化時數字鍵設定為 0 代表尚未執行過
    public Map<String, String> phonePools = new HashMap<>();

    @PostConstruct
    public void init() {
        //問券填寫的對象
        phonePools.put("0223xxxxxx", "0");

        logger.debug("URL:{}", calloutURL);
        logger.debug("serviceNumber:{}", serviceNumber);
        logger.debug("AuthKey:{}", apiKey);

        httpClient = new OkHttpClient.Builder()
//                .connectTimeout(15, TimeUnit.SECONDS)
//                .readTimeout(15, TimeUnit.SECONDS)
//                .retryOnConnectionFailure(true)
                .build();

        logger.debug("timeout:{}", httpClient.connectTimeoutMillis());
    }


    public String calloutIVR(JSONArray phones) {
        JSONObject calloutMsg = new JSONObject()
                .put("serviceNumber", serviceNumber)
                .put("phones", phones)
                .put("ivrData", new JSONObject()
                        .put("node", "MAIN")
                        .put("nextNode", "CUSTOM")
                );
        logger.debug("sent callout msg: {}", calloutMsg.toString(2));
        return calloutMsg.toString();
    }

    public void callout(String content) {
        MediaType type = MediaType.parse("application/json; charset=utf-8");
        RequestBody reqBody = RequestBody.create(content, type);

        logger.debug("URL:{}", calloutURL);

        Request request = new Request.Builder()
                .url(calloutURL)
                .addHeader("X-API-Key", apiKey)
                .post(reqBody)
                .build();

        logger.debug("do ap request");
        httpClient.newCall(request).enqueue(new Callback() {

            @Override
            public void onFailure(@NotNull Call call, @NotNull IOException ex) {
                logger.error("error:", ex);
            }

            @Override
            public void onResponse(@NotNull Call call, @NotNull Response response) {
                logger.debug("code:{}", response.code());
            }
        });
    }

}
